@@ -225,10 +225,9 @@ class GAuth(graphene.Mutation, description='Authenticate a user using google ide
                 username=authObj['email'],
                 first_name=authObj['given_name'],
                 last_name=authObj['family_name'],
-                isEmailVerified=True
             )
 
-        import_string(CHOWKIDAR_GAUTH_CALLBACK)(authObj)
+        import_string(CHOWKIDAR_GAUTH_CALLBACK)(authObj, user)
 
         if not import_string(ALLOW_USER_TO_LOGIN_ON_AUTH)(user):
             raise AuthError('User not allowed to login', code='FORBIDDEN')
